@@ -20,6 +20,10 @@ Class and functions to interact with the volumes: defined in compose files.
 """
 
 import re
+from copy import deepcopy
+from troposphere import Ref
+from troposphere import AWS_NO_VALUE
+from troposphere.efs import LifecyclePolicy, BackupPolicy
 
 from ecs_composex.common import keyisset, LOG
 
@@ -53,12 +57,12 @@ def handle_volume_str_config(service, config, volumes):
     :param list volumes:
     """
     volume_config = {"read_only": False}
-    path_pattern = r"(^[^:]+$)|(^[^:]+)(:\/[\d\w\/]+)(:ro$|:rw$)?"
-    path_finder = re.compile(path_pattern)
+    path_finder = re.compile(r"(^[^:]+$)|(^[^:]+)(?::(\/[\d\w\/]+))(?::(ro$|rw$))?")
     path_match = path_finder.match(config)
     if not path_match:
         raise ValueError(
-            f"Volume syntax {config} is invalid. Must follow the pattern", path_pattern
+            f"Volume syntax {config} is invalid. Must follow the pattern",
+            path_finder.pattern,
         )
     if path_match.groups()[0]:
         volume_config["source"] = path_match.groups()[0]
@@ -90,37 +94,96 @@ def handle_volume_dict_config(service, config, volumes):
     match_volumes_services_config(service, volume_config, volumes)
 
 
+def evaluate_efs_properties(definition):
+    """
+    Function to parse the definition in case user uses the docker cli definition for EFS
+
+    :return:
+    """
+    efs_keys = {
+        "backup_policy": ("BackupPolicy", str),
+        "lifecycle_policy": ("ThroughputMode", str),
+        "performance_mode": ("PerformanceMode", str),
+        "throughput_mode": ("PerformanceMode", str),
+        "provisioned_throughput": ("ProvisionedThroughputInMibps", (int, float)),
+    }
+    props = {}
+    if keyisset(ComposeVolume.driver_opts_key, definition) and isinstance(
+        definition[ComposeVolume.driver_opts_key], dict
+    ):
+        opts = definition[ComposeVolume.driver_opts_key]
+        for name, config in efs_keys.items():
+            if not keyisset(name, opts):
+                props[config[0]] = Ref(AWS_NO_VALUE)
+            elif not isinstance(opts[name], config[1]):
+                raise TypeError(
+                    f"Property {name} is of type",
+                    type(opts[name]),
+                    "Expected",
+                    config[1],
+                )
+            else:
+                props[config[0]] = opts[name]
+    return props
+
+
 class ComposeVolume(object):
     """
     Class to keep track of the Docker-compose Volumes
+
+    When properties are defined, the priority in evaluation goes
+    * x-efs
+    * driver
+    * driver_opts
+
+    Assumed local when none else defined.
     """
 
     main_key = "volumes"
+    driver_key = "driver"
     driver_opts_key = "driver_opts"
 
     def __init__(self, name, definition):
         self.name = name
         self.volume_name = name
-        self.efs_volume = (
-            definition["x-efs"]
-            if keyisset("x-efs", definition) and isinstance(definition["x-efs"], str)
-            else None
-        )
+        self.definition = deepcopy(definition)
+        self.is_shared = False
         self.services = []
         self.device = None
         self.cfn_fs = None
         self.cfn_ap = None
-        self.type = "local" if not self.efs_volume else "nfs"
-
-        if (
-            keyisset(self.driver_opts_key, definition)
-            and isinstance(definition[self.driver_opts_key], dict)
-            and keyisset("type", definition[self.driver_opts_key])
-            and isinstance(definition[self.driver_opts_key]["type"], str)
-            and definition[self.driver_opts_key]["type"] == "nfs"
-        ):
-            self.type = "efs"
-            if keyisset("device", definition[self.driver_opts_key]):
-                self.root_folder = definition[self.driver_opts_key]["device"]
-            if keyisset("o", definition[self.driver_opts_key]):
-                self.mount_options_raw = definition[self.driver_opts_key]["o"]
+        self.cfn_volume = None
+        self.efs_props = {}
+        self.type = "volume"
+        self.driver = "local"
+        self.efs_props = evaluate_efs_properties(self.definition)
+        if self.efs_props:
+            LOG.info("Identified properties as defined by Docker Plugin")
+            self.type = "bind"
+            self.driver = "nfs"
+        else:
+            if keyisset("x-efs", self.definition):
+                self.driver = "nfs"
+                self.type = "bind"
+                self.is_shared = True
+                self.efs_props = self.definition["x-efs"]
+            elif (
+                not keyisset("x-efs", self.definition)
+                and keyisset(self.driver_key, self.definition)
+                and not keyisset(self.driver_opts_key, self.definition)
+            ):
+                if self.definition[self.driver_key] == "local":
+                    self.type = "volume"
+                    self.driver = "local"
+                    self.efs_props = None
+                elif (
+                    self.definition[self.driver_key] == "nfs"
+                    or self.definition[self.driver_key] == "efs"
+                ):
+                    self.type = "bind"
+                    self.is_shared = True
+                    self.driver = "nfs"
+            else:
+                self.type = "volume"
+                self.driver = "local"
+                self.is_shared = False
