@@ -19,6 +19,7 @@
 Module for the ComposeXSettings class
 """
 
+from re import sub
 from copy import deepcopy
 from datetime import datetime as dt
 
@@ -45,6 +46,12 @@ from ecs_composex.iam import ROLE_ARN_ARG
 from ecs_composex.iam import validate_iam_role_arn
 from ecs_composex.utils.init_ecs import set_ecs_settings
 from ecs_composex.utils.init_s3 import create_bucket
+from ecs_composex.vpc.vpc_params import (
+    VPC_ID,
+    APP_SUBNETS,
+    PUBLIC_SUBNETS,
+    STORAGE_SUBNETS,
+)
 
 
 def render_services_ports(services):
@@ -373,10 +380,13 @@ class ComposeXSettings(object):
     ]
     all_commands = active_commands + validation_commands + neutral_commands
 
-    def __init__(self, content=None, profile_name=None, session=None, **kwargs):
+    def __init__(
+        self, content=None, profile_name=None, session=None, for_macro=False, **kwargs
+    ):
         """
         Class to init the configuration
         """
+        self.for_cfn_macro = for_macro
         self.session = boto3.session.Session()
         self.override_session(session, profile_name, kwargs)
         self.aws_region = (
@@ -397,7 +407,9 @@ class ComposeXSettings(object):
         self.secrets = []
         self.networks = []
         self.subnets_parameters = []
+        self.subnets_mappings = {}
         self.secrets_mappings = {}
+        self.mappings = {}
         self.families = {}
         self.account_id = None
         self.output_dir = self.default_output_dir
@@ -421,6 +433,7 @@ class ComposeXSettings(object):
         self.set_output_settings(kwargs)
         self.use_appmesh = keyisset("x-appmesh", self.compose_content)
         self.name = kwargs[self.name_arg]
+        self.ecs_cluster = None
 
     def set_secrets(self):
         """
@@ -502,27 +515,29 @@ class ComposeXSettings(object):
             )
             the_service = deepcopy(service)
             family = ComposeFamily([the_service], family_name)
-            self.families[family_name] = family
+            self.families[family.logical_name] = family
             the_service.my_family = family
             self.services.append(the_service)
         else:
             family = ComposeFamily([service], family_name)
             service.my_family = family
-        self.families[family_name] = family
+        self.families[family.logical_name] = family
         if service.name not in [service.name for service in assigned_services]:
             assigned_services.append(service)
 
     def handle_assigned_existing_service(self, family_name, service, assigned_services):
+        the_family = self.families[family_name]
         if service.name in [service.name for service in assigned_services]:
             LOG.info(
                 f"Detected {service.name} is-reused in different family. Making a deepcopy"
             )
+
             the_service = deepcopy(service)
-            self.families[family_name].add_service(the_service)
+            the_family.add_service(the_service)
             the_service.my_family = self.families[family_name]
             self.services.append(the_service)
         else:
-            self.families[family_name].add_service(service)
+            the_family.add_service(service)
             service.my_family = self.families[family_name]
             assigned_services.append(service)
 
@@ -534,17 +549,18 @@ class ComposeXSettings(object):
         assigned_services = []
         for service in self.services:
             for family_name in service.families:
-                if NONALPHANUM.findall(family_name):
+                formatted_name = sub(r"[^a-zA-Z0-9]+", "", family_name)
+                if NONALPHANUM.findall(formatted_name):
                     raise ValueError(
                         "Family names must be ^[a-zA-Z0-9]+$ | alphanumerical"
                     )
-                if family_name not in self.families.keys():
+                if formatted_name not in self.families.keys():
                     self.add_new_family(family_name, service, assigned_services)
-                elif family_name in self.families.keys() and service.name not in [
-                    service.name for service in self.families[family_name].services
+                elif formatted_name in self.families.keys() and service.name not in [
+                    service.name for service in self.families[formatted_name].services
                 ]:
                     self.handle_assigned_existing_service(
-                        family_name, service, assigned_services
+                        formatted_name, service, assigned_services
                     )
         LOG.debug([self.families[family] for family in self.families])
 
@@ -693,8 +709,11 @@ class ComposeXSettings(object):
             app_r = client.describe_subnets(SubnetIds=app_subnets)["Subnets"]
             storage_r = client.describe_subnets(SubnetIds=storage_subnets)["Subnets"]
             self.public_azs = [sub["AvailabilityZone"] for sub in public_r]
+            self.subnets_mappings[PUBLIC_SUBNETS.title]["Azs"] = self.public_azs
             self.storage_azs = [sub["AvailabilityZone"] for sub in storage_r]
+            self.subnets_mappings[STORAGE_SUBNETS.title]["Azs"] = self.storage_azs
             self.app_azs = [sub["AvailabilityZone"] for sub in app_r]
+            self.subnets_mappings[APP_SUBNETS.title]["Azs"] = self.app_azs
             LOG.info("Successfully updated self with AZs from looked up VPC subnets")
         except ClientError:
             LOG.warning("Could not define the AZs based on the imported subnets")
