@@ -20,11 +20,13 @@ Module to handle Root stacks and substacks in ECS composeX. Allows to treat ever
 files into S3 and on disk.
 """
 
-from troposphere import Template, GetAtt, Ref, If, Join, ImportValue
+from troposphere import Template, GetAtt, Ref, If, Join, ImportValue, FindInMap
+from troposphere import AWS_STACK_NAME
 from troposphere.cloudformation import Stack
 
 from ecs_composex.common import LOG, keyisset, add_parameters, NONALPHANUM
 from ecs_composex.common import cfn_conditions
+from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
 from ecs_composex.common.files import FileArtifact
 from ecs_composex.vpc.vpc_params import (
     VPC_ID,
@@ -83,6 +85,7 @@ class ComposeXStack(Stack, object):
         :param kwargs: kwargs from composex along with the kwargs for the stack
         """
         self.name = name
+        self.parent_stack = None
         title = NONALPHANUM.sub("", self.name)
         self.file_name = file_name if file_name else title
         self.lookup_resources = []
@@ -107,6 +110,25 @@ class ComposeXStack(Stack, object):
         if not hasattr(self, "DependsOn") or not keyisset("DependsOn", kwargs):
             self.DependsOn = []
 
+    def mark_nested_stacks(self):
+        """
+        Method to go over the stack resources, identify the nested stacks, and set a marker of the parent to them
+        """
+        if not self.stack_template:
+            return
+        for resource in self.stack_template.resources.values():
+            if issubclass(type(resource), ComposeXStack) or isinstance(
+                resource, ComposeXStack
+            ):
+                resource.parent_stack = self
+                resource.mark_nested_stacks()
+
+    def get_top_root_stack(self):
+        if self.parent_stack:
+            return self.parent_stack.get_top_root_stack()
+        else:
+            return self
+
     def add_dependencies(self, dependencies):
         """
         Function to add dependencies to DependsOn
@@ -250,7 +272,7 @@ class ComposeXStack(Stack, object):
         elif hasattr(self, "DependsOn") and vpc not in getattr(self, "DependsOn"):
             self.DependsOn.append(vpc)
 
-    def no_vpc_parameters(self):
+    def no_vpc_parameters(self, settings):
         """
         Method to set the stack parameters when we are not creating a VPC.
         """
@@ -260,18 +282,21 @@ class ComposeXStack(Stack, object):
             STORAGE_SUBNETS,
             APP_SUBNETS,
         ]
-        add_parameters(self.stack_template, default_parameters)
+        add_parameters(self.stack_template, settings.subnets_parameters)
         self.Parameters.update(
-            {
-                VPC_ID_T: Ref(VPC_ID),
-                APP_SUBNETS_T: Join(",", Ref(APP_SUBNETS)),
-                STORAGE_SUBNETS_T: Join(",", Ref(STORAGE_SUBNETS)),
-                PUBLIC_SUBNETS_T: Join(",", Ref(PUBLIC_SUBNETS)),
-            }
+            {VPC_ID_T: FindInMap("Network", VPC_ID.title, VPC_ID.title)}
         )
+        for subnet_param in settings.subnets_parameters:
+            self.Parameters.update(
+                {
+                    subnet_param.title: Join(
+                        ",", FindInMap("Network", subnet_param.title, "Ids")
+                    )
+                }
+            )
 
 
-def process_stacks(root_stack, settings):
+def process_stacks(root_stack, settings, is_root=True):
     """
     Function to go through all stacks of a given template and update the template
     It will recursively render sub stacks defined.
@@ -289,8 +314,11 @@ def process_stacks(root_stack, settings):
         ):
             LOG.debug(resource)
             LOG.debug(resource.title)
-            process_stacks(resource, settings)
-            resource.Parameters.update(cfn_conditions.pass_root_stack_name())
+            process_stacks(resource, settings, is_root=False)
+            if is_root:
+                resource.Parameters.update({ROOT_STACK_NAME_T: Ref(AWS_STACK_NAME)})
+            else:
+                resource.Parameters.update(cfn_conditions.pass_root_stack_name())
         elif isinstance(resource, Stack):
             LOG.warning(resource_name)
             LOG.warning(resource)
