@@ -40,3 +40,15 @@ USE_DEFAULT_ZONE_NAME_CON_T = "UseDefaultPrivateZoneName"
 USE_DEFAULT_ZONE_NAME_CON = Equals(
     Ref(dns_params.PRIVATE_DNS_ZONE_NAME), dns_params.PRIVATE_DNS_ZONE_NAME.Default
 )
+
+PRIVATE_ZONE_ID_CON_T = "PrivateNamespaceZoneIdCondition"
+PRIVATE_ZONE_ID_CON = Not(
+    Equals(Ref(dns_params.PRIVATE_DNS_ZONE_ID), dns_params.PRIVATE_DNS_ZONE_ID.Default)
+)
+
+PRIVATE_NAMESPACE_CON_T = "PrivateNamespaceIdCondition"
+PRIVATE_NAMESPACE_CON = Not(
+    Equals(
+        Ref(dns_params.PRIVATE_NAMESPACE_ID), dns_params.PRIVATE_NAMESPACE_ID.Default
+    )
+)
