@@ -26,12 +26,12 @@ from troposphere.ec2 import SecurityGroup
 from troposphere.iam import PolicyType
 from troposphere.logs import LogGroup
 
-from ecs_composex.common import build_template
+from ecs_composex.common import build_template, LOG
 from ecs_composex.common.cfn_params import (
     ROOT_STACK_NAME_T,
     ROOT_STACK_NAME,
 )
-from ecs_composex.dns import dns_params
+from ecs_composex.dns import dns_params, dns_conditions
 from ecs_composex.dns.dns_conditions import (
     CREATE_PUBLIC_NAMESPACE_CON_T,
     CREATE_PUBLIC_NAMESPACE_CON,
@@ -66,6 +66,7 @@ def initialize_service_template(service_name):
             dns_params.PRIVATE_DNS_ZONE_NAME,
             dns_params.PUBLIC_DNS_ZONE_ID,
             dns_params.PRIVATE_DNS_ZONE_ID,
+            dns_params.PRIVATE_NAMESPACE_ID,
             ecs_params.CLUSTER_NAME,
             ecs_params.LAUNCH_TYPE,
             ecs_params.ECS_CONTROLLER,
@@ -121,6 +122,12 @@ def initialize_service_template(service_name):
         ecs_conditions.GENERATED_LOG_GROUP_NAME_CON_T,
         ecs_conditions.GENERATED_LOG_GROUP_NAME_CON,
     )
+    service_tpl.add_condition(
+        dns_conditions.PRIVATE_ZONE_ID_CON_T, dns_conditions.PRIVATE_ZONE_ID_CON
+    )
+    service_tpl.add_condition(
+        dns_conditions.PRIVATE_NAMESPACE_CON_T, dns_conditions.PRIVATE_NAMESPACE_CON
+    )
     return service_tpl
 
 
@@ -284,18 +291,9 @@ def generate_services(settings):
                 ecs_params.SERVICE_NAME_T: family.logical_name,
                 CLUSTER_NAME_T: Ref(CLUSTER_NAME),
                 ROOT_STACK_NAME_T: Ref(ROOT_STACK_NAME),
-                dns_params.PRIVATE_DNS_ZONE_ID.title: Ref(
-                    dns_params.PRIVATE_DNS_ZONE_ID
-                ),
-                dns_params.PRIVATE_DNS_ZONE_NAME.title: Ref(
-                    dns_params.PRIVATE_DNS_ZONE_NAME
-                ),
-                dns_params.PUBLIC_DNS_ZONE_ID.title: Ref(dns_params.PUBLIC_DNS_ZONE_ID),
-                dns_params.PUBLIC_DNS_ZONE_NAME.title: Ref(
-                    dns_params.PUBLIC_DNS_ZONE_NAME
-                ),
             }
         )
         family.upload_services_env_files(settings)
         family.set_repository_credentials(settings)
         family.set_codeguru_profiles_arns()
+        family.set_volumes()
