@@ -22,14 +22,14 @@ Main module to generate a full stack with VPC, Cluster, Compute, Services and al
 import re
 from importlib import import_module
 
-from troposphere import Ref, AWS_STACK_NAME, GetAtt
+from troposphere import Ref, AWS_STACK_NAME, GetAtt, FindInMap
 
 from ecs_composex.acm.acm_params import RES_KEY as ACM_KEY
 from ecs_composex.acm.acm_stack import init_acm_certs
 from ecs_composex.appmesh.appmesh_mesh import Mesh
 from ecs_composex.common import LOG, NONALPHANUM
 from ecs_composex.common import (
-    build_template,
+    init_template,
     keyisset,
 )
 from ecs_composex.common.cfn_params import (
@@ -48,17 +48,10 @@ from ecs_composex.compute.compute_params import (
     MIN_CAPACITY_T,
 )
 from ecs_composex.compute.compute_stack import ComputeStack
-from ecs_composex.dns import add_parameters_and_conditions as dns_inputs, DnsSettings
+from ecs_composex.dns import DnsSettings
 from ecs_composex.dns.dns_records import DnsRecords
-from ecs_composex.ecs.ecs_stack import associate_services_to_root_stack
 from ecs_composex.ecs.ecs_cluster import add_ecs_cluster
-from ecs_composex.ecs.ecs_params import (
-    CLUSTER_NAME,
-    CLUSTER_T as ROOT_CLUSTER_NAME,
-    CREATE_CLUSTER,
-    FARGATE_VERSION,
-)
-from ecs_composex.ecs.ecs_conditions import CREATE_CLUSTER_CON_T, CREATE_CLUSTER_CON
+from ecs_composex.ecs.ecs_stack import associate_services_to_root_stack
 from ecs_composex.vpc import vpc_params
 from ecs_composex.vpc.vpc_stack import add_vpc_to_root
 
@@ -195,23 +188,22 @@ def apply_x_configs_to_ecs(settings, root_stack):
             invoke_x_to_ecs(None, settings, root_stack, resource)
 
 
-def apply_x_to_x_configs(root_template, settings):
+def apply_x_to_x_configs(root_stack, settings):
     """
     Function to iterate over each XStack and trigger cross-x resources configurations functions
 
-    :param troposphere.Template root_template: the ECS ComposeX root template
+    :param ComposeXStack root_stack: the ECS ComposeX root template
     :param ComposeXSettings settings: The execution settings
     :return:
     """
-    for resource_name in root_template.resources:
-        resource = root_template.resources[resource_name]
+    for resource_name, resource in root_stack.stack_template.resources.items():
         if (
             issubclass(type(resource), ComposeXStack)
-            and resource.name in SUPPORTED_X_MODULES
+            and resource.name in SUPPORTED_X_MODULE_NAMES
             and hasattr(resource, "add_xdependencies")
             and not resource.is_void
         ):
-            resource.add_xdependencies(root_template, settings.compose_content)
+            resource.add_xdependencies(root_stack, settings)
 
 
 def add_compute(root_template, settings, vpc_stack):
@@ -227,21 +219,16 @@ def add_compute(root_template, settings, vpc_stack):
     """
     if not settings.create_compute:
         return None
-    root_template.add_parameter(TARGET_CAPACITY)
-    parameters = {
-        ROOT_STACK_NAME_T: Ref(AWS_STACK_NAME),
-        TARGET_CAPACITY_T: Ref(TARGET_CAPACITY),
-        MIN_CAPACITY_T: Ref(TARGET_CAPACITY),
-        USE_FLEET_T: Ref(USE_FLEET),
-        USE_ONDEMAND_T: Ref(USE_ONDEMAND),
-    }
+    parameters = {ROOT_STACK_NAME_T: Ref(AWS_STACK_NAME)}
     compute_stack = ComputeStack(
         COMPUTE_STACK_NAME, settings=settings, parameters=parameters
     )
+    if isinstance(settings.ecs_cluster, Ref):
+        compute_stack.DependsOn.append(settings.ecs_cluster.data["Ref"])
     if vpc_stack is not None:
         compute_stack.get_from_vpc_stack(vpc_stack)
     else:
-        compute_stack.no_vpc_parameters()
+        compute_stack.no_vpc_parameters(settings)
     return root_template.add_resource(compute_stack)
 
 
@@ -278,7 +265,7 @@ def handle_new_xstack(
         if vpc_stack and key in TCP_SERVICES:
             xstack.get_from_vpc_stack(vpc_stack)
         elif not vpc_stack and key in TCP_SERVICES:
-            xstack.no_vpc_parameters()
+            xstack.no_vpc_parameters(settings)
 
 
 def add_x_resources(root_template, settings, services_stack, vpc_stack=None):
@@ -324,22 +311,18 @@ def get_vpc_id(vpc_stack):
     if vpc_stack:
         return GetAtt(VPC_STACK_NAME, f"Outputs.{vpc_params.VPC_ID_T}")
     else:
-        return Ref(vpc_params.VPC_ID)
+        return FindInMap("Network", vpc_params.VPC_ID.title, vpc_params.VPC_ID.title)
 
 
-def init_root_template():
+def init_root_template(settings):
     """
     Function to initialize the root template
 
     :return: template
     :rtype: troposphere.Template
     """
-
-    template = build_template(
-        "Root template generated via ECS ComposeX",
-        [USE_FLEET, USE_ONDEMAND, CLUSTER_NAME, CREATE_CLUSTER, FARGATE_VERSION],
-    )
-    template.add_condition(CREATE_CLUSTER_CON_T, CREATE_CLUSTER_CON)
+    template = init_template("Root template generated via ECS ComposeX")
+    template.add_mapping("ComposeXDefaults", {"ECS": {"PlatformVersion": "1.4.0"}})
     return template
 
 
@@ -354,20 +337,15 @@ def generate_full_template(settings):
     LOG.debug(settings)
     root_stack_title = NONALPHANUM.sub("", settings.name.title())
     root_stack = ComposeXStack(
-        root_stack_title, stack_template=init_root_template(), file_name=settings.name
+        root_stack_title,
+        stack_template=init_root_template(settings),
+        file_name=settings.name,
     )
-    dns_inputs(root_stack)
     vpc_stack = add_vpc_to_root(root_stack, settings)
     settings.set_networks(vpc_stack, root_stack)
     dns_settings = DnsSettings(root_stack, settings, get_vpc_id(vpc_stack))
-    root_stack.Parameters.update(dns_settings.root_params)
-    add_ecs_cluster(settings, root_stack)
-    compute_stack = add_compute(root_stack.stack_template, settings, vpc_stack)
-    if settings.create_compute and compute_stack:
-        compute_stack.DependsOn.append(ROOT_CLUSTER_NAME)
-    associate_services_to_root_stack(
-        root_stack, settings, dns_settings.nested_params, vpc_stack
-    )
+    settings.ecs_cluster = add_ecs_cluster(root_stack, settings)
+    associate_services_to_root_stack(root_stack, settings, vpc_stack)
     if keyisset(ACM_KEY, settings.compose_content):
         init_acm_certs(settings, dns_settings, root_stack)
     add_x_resources(
@@ -380,11 +358,14 @@ def generate_full_template(settings):
         settings,
         root_stack,
     )
-    apply_x_to_x_configs(root_stack.stack_template, settings)
-    if keyisset("x-appmesh", settings.compose_content):
-        mesh = Mesh(settings.compose_content["x-appmesh"], root_stack, settings)
-        mesh.render_mesh_template(root_stack)
+    apply_x_to_x_configs(root_stack, settings)
+    if settings.use_appmesh:
+        mesh = Mesh(
+            settings.compose_content["x-appmesh"], root_stack, settings, dns_settings
+        )
+        mesh.render_mesh_template(root_stack, settings, dns_settings)
     dns_records = DnsRecords(settings)
     dns_records.associate_records_to_resources(settings, root_stack, dns_settings)
+    dns_settings.associate_settings_to_nested_stacks(root_stack)
     add_all_tags(root_stack.stack_template, settings)
     return root_stack
