@@ -48,10 +48,11 @@ from ecs_composex.ecs.ecs_params import (
 from ecs_composex.vpc.vpc_params import APP_SUBNETS, SG_ID_TYPE, SUBNETS_TYPE
 
 
-def define_service_targets(stack, rule, cluster_arn):
+def define_service_targets(settings, stack, rule, cluster_arn):
     """
     Function to define the targets for service.
 
+    :param ecs_composex.common.settings.ComposeXSettings settings:
     :param ecs_composex.events.events_stack.XStack stack:
     :param ecs_composex.events.events_stack.Rule rule:
     :param troposphere.Sub cluster_arn:
@@ -173,7 +174,7 @@ def define_service_targets(stack, rule, cluster_arn):
             EcsParameters=EcsParameters(
                 NetworkConfiguration=NetworkConfiguration(
                     AwsVpcConfiguration=AwsVpcConfiguration(
-                        Subnets=Ref(service_sg_param),
+                        Subnets=Ref(service_subnets_param),
                         SecurityGroups=[Ref(service_sg_param)],
                     )
                 ),
@@ -210,7 +211,7 @@ def events_to_ecs(resources, services_stack, res_root_stack, settings):
     :param resources:
     :param services_stack:
     :param res_root_stack:
-    :param settings:
+    :param ecs_composex.common.settings.ComposeXSettings settings:
     :return:
     """
     cluster_arn = Sub(
@@ -224,4 +225,4 @@ def events_to_ecs(resources, services_stack, res_root_stack, settings):
     ]
     for rule in rules:
         if rule.families_targets:
-            define_service_targets(res_root_stack, rule, cluster_arn)
+            define_service_targets(settings, res_root_stack, rule, cluster_arn)
