@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -53,7 +53,8 @@ def handle_import_dbs_to_services(db, rds_mapping, target, mapping_name):
             add_secret_to_container(
                 db,
                 FindInMap(mapping_name, db.logical_name, DB_SECRET_T),
-                service.container_definition,
+                service,
+                target,
             )
         add_secrets_access_policy(
             target[0].template,
