@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -22,15 +22,19 @@ based on pre-defined SQS policies for consumers
 
 from os import path
 from json import loads
+from ecs_composex.iam.import_sam_policies import import_and_cleanse_policies
 
 
 def get_access_types():
+    sam_policies = import_and_cleanse_policies()
     with open(
         f"{path.abspath(path.dirname(__file__))}/sqs_perms.json",
         "r",
         encoding="utf-8-sig",
     ) as perms_fd:
-        return loads(perms_fd.read())
+        sqs_policies = loads(perms_fd.read())
+    sam_policies.update(sqs_policies)
+    return sam_policies
 
 
 ACCESS_TYPES = get_access_types()
