@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -71,18 +71,20 @@ class Queue(XResource):
 
     def init_outputs(self):
         self.output_properties = {
-            SQS_URL.title: (self.logical_name, self.cfn_resource, Ref, None),
+            SQS_URL.title: (self.logical_name, self.cfn_resource, Ref, None, "Url"),
             SQS_ARN.title: (
                 f"{self.logical_name}{SQS_ARN.title}",
                 self.cfn_resource,
                 GetAtt,
                 SQS_ARN.title,
+                "Arn",
             ),
             SQS_NAME.title: (
                 f"{self.logical_name}{SQS_NAME.title}",
                 self.cfn_resource,
                 GetAtt,
                 SQS_NAME.title,
+                "QueueName",
             ),
         }
 
